#[unsafe(no_mangle)]pub unsafe extern "C" fn order_list_id_new(
ptr: *const c_char,
) -> OrderListIdExpand description
Returns a Nautilus identifier from a C string pointer.
Safety
Assumes ptr is a valid C string pointer.
#[unsafe(no_mangle)]pub unsafe extern "C" fn order_list_id_new(
ptr: *const c_char,
) -> OrderListIdReturns a Nautilus identifier from a C string pointer.
Assumes ptr is a valid C string pointer.